==> openGion7.2.0.0_dev.zip: uap/webapps/ge/db/MYSQL/sql/install/01_TABLE/GE30S.sql <==
/****************************************************************************/
/* GE30 ( ﾊﾟﾗﾒｰﾀﾃｰﾌﾞﾙ )                                                     */
/*                                                                          */
/* Created : 2018/09/28 16:03:25                                            */
/****************************************************************************/

CREATE TABLE GE30 (
   SYSTEM_ID    VARCHAR (  10 )                 NOT NULL                                                /*  10 ｼｽﾃﾑID           */
 , PTN_ID       VARCHAR (  20 )                 NOT NULL                                                /*  20 定型文ID         */
 , FROM_ID      VARCHAR (  50 )                 NOT NULL                                                /*  30 送信者ID         */
 , TO_ID        TEXT                                                                                    /*  40 宛先(TO)         */
 , CC_ID        TEXT                                                                                    /*  50 宛先(CC)         */
 , BCC_ID       TEXT                                                                                    /*  60 宛先(BCC)        */
 , H_TXT        TEXT                                                                                    /*  70 ﾍｯﾀﾞｰ自由文      */
 , F_TXT        TEXT                                                                                    /*  80 ﾌｯﾀｰ自由文       */
 , GAMEN_URL    VARCHAR ( 300 )                                                                         /*  90 画面URL(暗号化)  */
 , PARAM0       TEXT                                                                                    /* 100 ﾊﾟﾗﾒｰﾀ0          */
 , PARAM1       TEXT                                                                                    /* 110 ﾊﾟﾗﾒｰﾀ1          */
 , PARAM2       TEXT                                                                                    /* 120 ﾊﾟﾗﾒｰﾀ2          */
 , PARAM3       TEXT                                                                                    /* 130 ﾊﾟﾗﾒｰﾀ3          */
 , PARAM4       TEXT                                                                                    /* 140 ﾊﾟﾗﾒｰﾀ4          */
 , PARAM5       TEXT                                                                                    /* 150 ﾊﾟﾗﾒｰﾀ5          */
 , PARAM6       TEXT                                                                                    /* 160 ﾊﾟﾗﾒｰﾀ6          */
 , PARAM7       TEXT                                                                                    /* 170 ﾊﾟﾗﾒｰﾀ7          */
 , PARAM8       TEXT                                                                                    /* 180 ﾊﾟﾗﾒｰﾀ8          */
 , PARAM9       TEXT                                                                                    /* 190 ﾊﾟﾗﾒｰﾀ9          */
 , ATTACH1      VARCHAR ( 256 )                                                                         /* 200 添付1            */
 , ATTACH2      VARCHAR ( 256 )                                                                         /* 210 添付2            */
 , ATTACH3      VARCHAR ( 256 )                                                                         /* 220 添付3            */
 , ATTACH4      VARCHAR ( 256 )                                                                         /* 230 添付4            */
 , ATTACH5      VARCHAR ( 256 )                                                                         /* 240 添付5            */
 , SNDTIME      VARCHAR (  14 )                                                                         /* 250 送信日時         */
 , UNIQ         BIGINT                          NOT NULL    AUTO_INCREMENT  , PRIMARY KEY(UNIQ)         /* 800 ﾕﾆｰｸｷｰ           */
 , FGJ          VARCHAR (   1 )     DEFAULT '1' NOT NULL                                                /* 810 状態ﾌﾗｸﾞ         */
 , DYSET        VARCHAR (  14 )                                                                         /* 820 登録日時         */
 , PGSET        VARCHAR (  10 )                                                                         /* 830 作成PG           */
 , PGPSET       VARCHAR (  10 )                                                                         /* 840 作成親PG         */
 , USRSET       VARCHAR (  10 )                                                                         /* 850 作成者           */
 , DYUPD        VARCHAR (  14 )                                                                         /* 860 更新日時         */
 , PGUPD        VARCHAR (  10 )                                                                         /* 870 更新PG           */
 , PGPUPD       VARCHAR (  10 )                                                                         /* 880 更新親PG         */
 , USRUPD       VARCHAR (  10 )                                                                         /* 890 更新者           */
);

==> openGion7.4.0.0_dev.zip: uap/webapps/ge/db/MYSQL/sql/install/01_TABLE/GE30S.sql <==
/****************************************************************************/
/* GE30 ( ﾊﾟﾗﾒｰﾀﾃｰﾌﾞﾙ )                                                     */
/*                                                                          */
/* Created : 2020/12/16 08:14:03                                            */
/****************************************************************************/

CREATE TABLE GE30 (
   SYSTEM_ID    VARCHAR (  10 )                 NOT NULL                                                /*  10 ｼｽﾃﾑID           */
 , PTN_ID       VARCHAR (  20 )                 NOT NULL                                                /*  20 定型文ID         */
 , FROM_ID      VARCHAR (  50 )                 NOT NULL                                                /*  30 送信者ID         */
 , TO_ID        TEXT                                                                                    /*  40 宛先(TO)         */
 , CC_ID        TEXT                                                                                    /*  50 宛先(CC)         */
 , BCC_ID       TEXT                                                                                    /*  60 宛先(BCC)        */
 , H_TXT        TEXT                                                                                    /*  70 ﾍｯﾀﾞｰ自由文      */
 , F_TXT        TEXT                                                                                    /*  80 ﾌｯﾀｰ自由文       */
 , GAMEN_URL    VARCHAR ( 300 )                                                                         /*  90 画面URL(暗号化)  */
 , PARAM0       TEXT                                                                                    /* 100 ﾊﾟﾗﾒｰﾀ0          */
 , PARAM1       TEXT                                                                                    /* 110 ﾊﾟﾗﾒｰﾀ1          */
 , PARAM2       TEXT                                                                                    /* 120 ﾊﾟﾗﾒｰﾀ2          */
 , PARAM3       TEXT                                                                                    /* 130 ﾊﾟﾗﾒｰﾀ3          */
 , PARAM4       TEXT                                                                                    /* 140 ﾊﾟﾗﾒｰﾀ4          */
 , PARAM5       TEXT                                                                                    /* 150 ﾊﾟﾗﾒｰﾀ5          */
 , PARAM6       TEXT                                                                                    /* 160 ﾊﾟﾗﾒｰﾀ6          */
 , PARAM7       TEXT                                                                                    /* 170 ﾊﾟﾗﾒｰﾀ7          */
 , PARAM8       TEXT                                                                                    /* 180 ﾊﾟﾗﾒｰﾀ8          */
 , PARAM9       TEXT                                                                                    /* 190 ﾊﾟﾗﾒｰﾀ9          */
 , ATTACH1      VARCHAR ( 256 )                                                                         /* 200 添付1            */
 , ATTACH2      VARCHAR ( 256 )                                                                         /* 210 添付2            */
 , ATTACH3      VARCHAR ( 256 )                                                                         /* 220 添付3            */
 , ATTACH4      VARCHAR ( 256 )                                                                         /* 230 添付4            */
 , ATTACH5      VARCHAR ( 256 )                                                                         /* 240 添付5            */
 , SNDTIME      VARCHAR (  14 )                                                                         /* 250 送信日時         */
 , UNIQ         BIGINT                          NOT NULL    AUTO_INCREMENT  , PRIMARY KEY(UNIQ)         /* 800 ﾕﾆｰｸｷｰ           */
 , FGJ          VARCHAR (   1 )     DEFAULT '1' NOT NULL                                                /* 810 状態ﾌﾗｸﾞ         */
 , DYSET        VARCHAR (  14 )                                                                         /* 820 作成日時         */
 , PGSET        VARCHAR (  10 )                                                                         /* 830 作成PG           */
 , PGPSET       VARCHAR (  10 )                                                                         /* 840 作成親PG         */
 , USRSET       VARCHAR (  10 )                                                                         /* 850 作成者           */
 , DYUPD        VARCHAR (  14 )                                                                         /* 860 更新日時         */
 , PGUPD        VARCHAR (  10 )                                                                         /* 870 更新PG           */
 , PGPUPD       VARCHAR (  10 )                                                                         /* 880 更新親PG         */
 , USRUPD       VARCHAR (  10 )                                                                         /* 890 更新者           */
);
